==> Spire.Xls-13.9.0-py3-none-win_amd64.whl: spire/xls/CheckBoxCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class CheckBoxCollection (  CollectionBase[XlsCheckBoxShape],ICheckBoxes) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->ICheckBox:
        """

        """
        
        GetDllLibXls().CheckBoxCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().CheckBoxCollection_get_Item.restype=c_void_p
        intPtr = GetDllLibXls().CheckBoxCollection_get_Item(self.Ptr, index)
        ret = None if intPtr==None else XlsCheckBoxShape(intPtr)
        return ret


    @dispatch

    def get_Item(self ,name:str)->ICheckBox:
        """

        """
        
        GetDllLibXls().CheckBoxCollection_get_ItemN.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().CheckBoxCollection_get_ItemN.restype=c_void_p
        intPtr = GetDllLibXls().CheckBoxCollection_get_ItemN(self.Ptr, name)
        ret = None if intPtr==None else XlsCheckBoxShape(intPtr)
        return ret



    def AddCopy(self ,checkboxsource:'ICheckBox'):
        """

        """
        intPtrcheckboxsource:c_void_p = checkboxsource.Ptr

        GetDllLibXls().CheckBoxCollection_AddCopy.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().CheckBoxCollection_AddCopy(self.Ptr, intPtrcheckboxsource)


    def AddCheckBox(self ,row:int,column:int,height:int,width:int)->'ICheckBox':
        """

        """
        
        GetDllLibXls().CheckBoxCollection_AddCheckBox.argtypes=[c_void_p ,c_int,c_int,c_int,c_int]
        GetDllLibXls().CheckBoxCollection_AddCheckBox.restype=c_void_p
        intPtr = GetDllLibXls().CheckBoxCollection_AddCheckBox(self.Ptr, row,column,height,width)
        ret = None if intPtr==None else XlsCheckBoxShape(intPtr)
        return ret


    def Clear(self):
        """

        """
        GetDllLibXls().CheckBoxCollection_Clear.argtypes=[c_void_p]
        GetDllLibXls().CheckBoxCollection_Clear(self.Ptr)

==> Spire.Xls-14.4.4-py3-none-win_amd64.whl: spire/xls/CheckBoxCollection.py <==
from enum import Enum
from plum import dispatch
from typing import TypeVar,Union,Generic,List,Tuple
from spire.xls.common import *
from spire.xls import *
from ctypes import *
import abc

class CheckBoxCollection (  CollectionBase[XlsCheckBoxShape],ICheckBoxes) :
    """

    """
    @dispatch

    def get_Item(self ,index:int)->ICheckBox:
        """

        """
        
        GetDllLibXls().CheckBoxCollection_get_Item.argtypes=[c_void_p ,c_int]
        GetDllLibXls().CheckBoxCollection_get_Item.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().CheckBoxCollection_get_Item, self.Ptr, index)
        ret = None if intPtr==None else XlsCheckBoxShape(intPtr)
        return ret


    @dispatch

    def get_Item(self ,name:str)->ICheckBox:
        """

        """
        
        GetDllLibXls().CheckBoxCollection_get_ItemN.argtypes=[c_void_p ,c_void_p]
        GetDllLibXls().CheckBoxCollection_get_ItemN.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().CheckBoxCollection_get_ItemN, self.Ptr, name)
        ret = None if intPtr==None else XlsCheckBoxShape(intPtr)
        return ret



    def AddCopy(self ,checkboxsource:'ICheckBox'):
        """

        """
        intPtrcheckboxsource:c_void_p = checkboxsource.Ptr

        GetDllLibXls().CheckBoxCollection_AddCopy.argtypes=[c_void_p ,c_void_p]
        CallCFunction(GetDllLibXls().CheckBoxCollection_AddCopy, self.Ptr, intPtrcheckboxsource)


    def AddCheckBox(self ,row:int,column:int,height:int,width:int)->'ICheckBox':
        """

        """
        
        GetDllLibXls().CheckBoxCollection_AddCheckBox.argtypes=[c_void_p ,c_int,c_int,c_int,c_int]
        GetDllLibXls().CheckBoxCollection_AddCheckBox.restype=c_void_p
        intPtr = CallCFunction(GetDllLibXls().CheckBoxCollection_AddCheckBox, self.Ptr, row,column,height,width)
        ret = None if intPtr==None else XlsCheckBoxShape(intPtr)
        return ret


    def Clear(self):
        """

        """
        GetDllLibXls().CheckBoxCollection_Clear.argtypes=[c_void_p]
        CallCFunction(GetDllLibXls().CheckBoxCollection_Clear, self.Ptr)
